# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/feed_item.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.common import custom_parameter_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_custom__parameter__pb2
from google.ads.google_ads.v2.proto.common import feed_common_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_feed__common__pb2
from google.ads.google_ads.v2.proto.common import policy_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_policy__pb2
from google.ads.google_ads.v2.proto.enums import feed_item_quality_approval_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__quality__approval__status__pb2
from google.ads.google_ads.v2.proto.enums import feed_item_quality_disapproval_reason_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__quality__disapproval__reason__pb2
from google.ads.google_ads.v2.proto.enums import feed_item_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__status__pb2
from google.ads.google_ads.v2.proto.enums import feed_item_validation_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__validation__status__pb2
from google.ads.google_ads.v2.proto.enums import geo_targeting_restriction_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_geo__targeting__restriction__pb2
from google.ads.google_ads.v2.proto.enums import placeholder_type_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_placeholder__type__pb2
from google.ads.google_ads.v2.proto.enums import policy_approval_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_policy__approval__status__pb2
from google.ads.google_ads.v2.proto.enums import policy_review_status_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_policy__review__status__pb2
from google.ads.google_ads.v2.proto.errors import feed_item_validation_error_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_feed__item__validation__error__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/feed_item.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\rFeedItemProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\n7google/ads/googleads_v2/proto/resources/feed_item.proto\x12!google.ads.googleads.v2.resources\x1a;google/ads/googleads_v2/proto/common/custom_parameter.proto\x1a\x36google/ads/googleads_v2/proto/common/feed_common.proto\x1a\x31google/ads/googleads_v2/proto/common/policy.proto\x1aKgoogle/ads/googleads_v2/proto/enums/feed_item_quality_approval_status.proto\x1aNgoogle/ads/googleads_v2/proto/enums/feed_item_quality_disapproval_reason.proto\x1a:google/ads/googleads_v2/proto/enums/feed_item_status.proto\x1a\x45google/ads/googleads_v2/proto/enums/feed_item_validation_status.proto\x1a\x43google/ads/googleads_v2/proto/enums/geo_targeting_restriction.proto\x1a:google/ads/googleads_v2/proto/enums/placeholder_type.proto\x1a@google/ads/googleads_v2/proto/enums/policy_approval_status.proto\x1a>google/ads/googleads_v2/proto/enums/policy_review_status.proto\x1a\x45google/ads/googleads_v2/proto/errors/feed_item_validation_error.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xa8\x05\n\x08\x46\x65\x65\x64Item\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12*\n\x04\x66\x65\x65\x64\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\'\n\x02id\x18\x03 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x35\n\x0fstart_date_time\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rend_date_time\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12S\n\x10\x61ttribute_values\x18\x06 \x03(\x0b\x32\x39.google.ads.googleads.v2.resources.FeedItemAttributeValue\x12u\n\x19geo_targeting_restriction\x18\x07 \x01(\x0e\x32R.google.ads.googleads.v2.enums.GeoTargetingRestrictionEnum.GeoTargetingRestriction\x12N\n\x15url_custom_parameters\x18\x08 \x03(\x0b\x32/.google.ads.googleads.v2.common.CustomParameter\x12P\n\x06status\x18\t \x01(\x0e\x32@.google.ads.googleads.v2.enums.FeedItemStatusEnum.FeedItemStatus\x12V\n\x0cpolicy_infos\x18\n \x03(\x0b\x32@.google.ads.googleads.v2.resources.FeedItemPlaceholderPolicyInfo\"\xae\x04\n\x16\x46\x65\x65\x64ItemAttributeValue\x12\x36\n\x11\x66\x65\x65\x64_attribute_id\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x32\n\rinteger_value\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x31\n\rboolean_value\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x32\n\x0cstring_value\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x32\n\x0c\x64ouble_value\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.DoubleValue\x12:\n\x0bprice_value\x18\x06 \x01(\x0b\x32%.google.ads.googleads.v2.common.Money\x12\x33\n\x0einteger_values\x18\x07 \x03(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x32\n\x0e\x62oolean_values\x18\x08 \x03(\x0b\x32\x1a.google.protobuf.BoolValue\x12\x33\n\rstring_values\x18\t \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rdouble_values\x18\n \x03(\x0b\x32\x1c.google.protobuf.DoubleValue\"\xb1\x07\n\x1d\x46\x65\x65\x64ItemPlaceholderPolicyInfo\x12\x61\n\x15placeholder_type_enum\x18\n \x01(\x0e\x32\x42.google.ads.googleads.v2.enums.PlaceholderTypeEnum.PlaceholderType\x12@\n\x1a\x66\x65\x65\x64_mapping_resource_name\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12_\n\rreview_status\x18\x03 \x01(\x0e\x32H.google.ads.googleads.v2.enums.PolicyReviewStatusEnum.PolicyReviewStatus\x12\x65\n\x0f\x61pproval_status\x18\x04 \x01(\x0e\x32L.google.ads.googleads.v2.enums.PolicyApprovalStatusEnum.PolicyApprovalStatus\x12N\n\x14policy_topic_entries\x18\x05 \x03(\x0b\x32\x30.google.ads.googleads.v2.common.PolicyTopicEntry\x12o\n\x11validation_status\x18\x06 \x01(\x0e\x32T.google.ads.googleads.v2.enums.FeedItemValidationStatusEnum.FeedItemValidationStatus\x12U\n\x11validation_errors\x18\x07 \x03(\x0b\x32:.google.ads.googleads.v2.resources.FeedItemValidationError\x12\x7f\n\x17quality_approval_status\x18\x08 \x01(\x0e\x32^.google.ads.googleads.v2.enums.FeedItemQualityApprovalStatusEnum.FeedItemQualityApprovalStatus\x12\x89\x01\n\x1bquality_disapproval_reasons\x18\t \x03(\x0e\x32\x64.google.ads.googleads.v2.enums.FeedItemQualityDisapprovalReasonEnum.FeedItemQualityDisapprovalReason\"\xa6\x02\n\x17\x46\x65\x65\x64ItemValidationError\x12m\n\x10validation_error\x18\x01 \x01(\x0e\x32S.google.ads.googleads.v2.errors.FeedItemValidationErrorEnum.FeedItemValidationError\x12\x31\n\x0b\x64\x65scription\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x37\n\x12\x66\x65\x65\x64_attribute_ids\x18\x03 \x03(\x0b\x32\x1b.google.protobuf.Int64Value\x12\x30\n\nextra_info\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\xfa\x01\n%com.google.ads.googleads.v2.resourcesB\rFeedItemProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_custom__parameter__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_feed__common__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_policy__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__quality__approval__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__quality__disapproval__reason__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__validation__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_geo__targeting__restriction__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_placeholder__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_policy__approval__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_policy__review__status__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_feed__item__validation__error__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_FEEDITEM = _descriptor.Descriptor(
  name='FeedItem',
  full_name='google.ads.googleads.v2.resources.FeedItem',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.FeedItem.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed', full_name='google.ads.googleads.v2.resources.FeedItem.feed', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='id', full_name='google.ads.googleads.v2.resources.FeedItem.id', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='start_date_time', full_name='google.ads.googleads.v2.resources.FeedItem.start_date_time', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='end_date_time', full_name='google.ads.googleads.v2.resources.FeedItem.end_date_time', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='attribute_values', full_name='google.ads.googleads.v2.resources.FeedItem.attribute_values', index=5,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='geo_targeting_restriction', full_name='google.ads.googleads.v2.resources.FeedItem.geo_targeting_restriction', index=6,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='url_custom_parameters', full_name='google.ads.googleads.v2.resources.FeedItem.url_custom_parameters', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v2.resources.FeedItem.status', index=8,
      number=9, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='policy_infos', full_name='google.ads.googleads.v2.resources.FeedItem.policy_infos', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=943,
  serialized_end=1623,
)


_FEEDITEMATTRIBUTEVALUE = _descriptor.Descriptor(
  name='FeedItemAttributeValue',
  full_name='google.ads.googleads.v2.resources.FeedItemAttributeValue',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='feed_attribute_id', full_name='google.ads.googleads.v2.resources.FeedItemAttributeValue.feed_attribute_id', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='integer_value', full_name='google.ads.googleads.v2.resources.FeedItemAttributeValue.integer_value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='boolean_value', full_name='google.ads.googleads.v2.resources.FeedItemAttributeValue.boolean_value', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='google.ads.googleads.v2.resources.FeedItemAttributeValue.string_value', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='double_value', full_name='google.ads.googleads.v2.resources.FeedItemAttributeValue.double_value', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='price_value', full_name='google.ads.googleads.v2.resources.FeedItemAttributeValue.price_value', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='integer_values', full_name='google.ads.googleads.v2.resources.FeedItemAttributeValue.integer_values', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='boolean_values', full_name='google.ads.googleads.v2.resources.FeedItemAttributeValue.boolean_values', index=7,
      number=8, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_values', full_name='google.ads.googleads.v2.resources.FeedItemAttributeValue.string_values', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='double_values', full_name='google.ads.googleads.v2.resources.FeedItemAttributeValue.double_values', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1626,
  serialized_end=2184,
)


_FEEDITEMPLACEHOLDERPOLICYINFO = _descriptor.Descriptor(
  name='FeedItemPlaceholderPolicyInfo',
  full_name='google.ads.googleads.v2.resources.FeedItemPlaceholderPolicyInfo',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='placeholder_type_enum', full_name='google.ads.googleads.v2.resources.FeedItemPlaceholderPolicyInfo.placeholder_type_enum', index=0,
      number=10, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_mapping_resource_name', full_name='google.ads.googleads.v2.resources.FeedItemPlaceholderPolicyInfo.feed_mapping_resource_name', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='review_status', full_name='google.ads.googleads.v2.resources.FeedItemPlaceholderPolicyInfo.review_status', index=2,
      number=3, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='approval_status', full_name='google.ads.googleads.v2.resources.FeedItemPlaceholderPolicyInfo.approval_status', index=3,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='policy_topic_entries', full_name='google.ads.googleads.v2.resources.FeedItemPlaceholderPolicyInfo.policy_topic_entries', index=4,
      number=5, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validation_status', full_name='google.ads.googleads.v2.resources.FeedItemPlaceholderPolicyInfo.validation_status', index=5,
      number=6, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='validation_errors', full_name='google.ads.googleads.v2.resources.FeedItemPlaceholderPolicyInfo.validation_errors', index=6,
      number=7, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quality_approval_status', full_name='google.ads.googleads.v2.resources.FeedItemPlaceholderPolicyInfo.quality_approval_status', index=7,
      number=8, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='quality_disapproval_reasons', full_name='google.ads.googleads.v2.resources.FeedItemPlaceholderPolicyInfo.quality_disapproval_reasons', index=8,
      number=9, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2187,
  serialized_end=3132,
)


_FEEDITEMVALIDATIONERROR = _descriptor.Descriptor(
  name='FeedItemValidationError',
  full_name='google.ads.googleads.v2.resources.FeedItemValidationError',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='validation_error', full_name='google.ads.googleads.v2.resources.FeedItemValidationError.validation_error', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='description', full_name='google.ads.googleads.v2.resources.FeedItemValidationError.description', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='feed_attribute_ids', full_name='google.ads.googleads.v2.resources.FeedItemValidationError.feed_attribute_ids', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='extra_info', full_name='google.ads.googleads.v2.resources.FeedItemValidationError.extra_info', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3135,
  serialized_end=3429,
)

_FEEDITEM.fields_by_name['feed'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEEDITEM.fields_by_name['id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_FEEDITEM.fields_by_name['start_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEEDITEM.fields_by_name['end_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEEDITEM.fields_by_name['attribute_values'].message_type = _FEEDITEMATTRIBUTEVALUE
_FEEDITEM.fields_by_name['geo_targeting_restriction'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_geo__targeting__restriction__pb2._GEOTARGETINGRESTRICTIONENUM_GEOTARGETINGRESTRICTION
_FEEDITEM.fields_by_name['url_custom_parameters'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_custom__parameter__pb2._CUSTOMPARAMETER
_FEEDITEM.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__status__pb2._FEEDITEMSTATUSENUM_FEEDITEMSTATUS
_FEEDITEM.fields_by_name['policy_infos'].message_type = _FEEDITEMPLACEHOLDERPOLICYINFO
_FEEDITEMATTRIBUTEVALUE.fields_by_name['feed_attribute_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_FEEDITEMATTRIBUTEVALUE.fields_by_name['integer_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_FEEDITEMATTRIBUTEVALUE.fields_by_name['boolean_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_FEEDITEMATTRIBUTEVALUE.fields_by_name['string_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEEDITEMATTRIBUTEVALUE.fields_by_name['double_value'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_FEEDITEMATTRIBUTEVALUE.fields_by_name['price_value'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_feed__common__pb2._MONEY
_FEEDITEMATTRIBUTEVALUE.fields_by_name['integer_values'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_FEEDITEMATTRIBUTEVALUE.fields_by_name['boolean_values'].message_type = google_dot_protobuf_dot_wrappers__pb2._BOOLVALUE
_FEEDITEMATTRIBUTEVALUE.fields_by_name['string_values'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEEDITEMATTRIBUTEVALUE.fields_by_name['double_values'].message_type = google_dot_protobuf_dot_wrappers__pb2._DOUBLEVALUE
_FEEDITEMPLACEHOLDERPOLICYINFO.fields_by_name['placeholder_type_enum'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_placeholder__type__pb2._PLACEHOLDERTYPEENUM_PLACEHOLDERTYPE
_FEEDITEMPLACEHOLDERPOLICYINFO.fields_by_name['feed_mapping_resource_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEEDITEMPLACEHOLDERPOLICYINFO.fields_by_name['review_status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_policy__review__status__pb2._POLICYREVIEWSTATUSENUM_POLICYREVIEWSTATUS
_FEEDITEMPLACEHOLDERPOLICYINFO.fields_by_name['approval_status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_policy__approval__status__pb2._POLICYAPPROVALSTATUSENUM_POLICYAPPROVALSTATUS
_FEEDITEMPLACEHOLDERPOLICYINFO.fields_by_name['policy_topic_entries'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_common_dot_policy__pb2._POLICYTOPICENTRY
_FEEDITEMPLACEHOLDERPOLICYINFO.fields_by_name['validation_status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__validation__status__pb2._FEEDITEMVALIDATIONSTATUSENUM_FEEDITEMVALIDATIONSTATUS
_FEEDITEMPLACEHOLDERPOLICYINFO.fields_by_name['validation_errors'].message_type = _FEEDITEMVALIDATIONERROR
_FEEDITEMPLACEHOLDERPOLICYINFO.fields_by_name['quality_approval_status'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__quality__approval__status__pb2._FEEDITEMQUALITYAPPROVALSTATUSENUM_FEEDITEMQUALITYAPPROVALSTATUS
_FEEDITEMPLACEHOLDERPOLICYINFO.fields_by_name['quality_disapproval_reasons'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_enums_dot_feed__item__quality__disapproval__reason__pb2._FEEDITEMQUALITYDISAPPROVALREASONENUM_FEEDITEMQUALITYDISAPPROVALREASON
_FEEDITEMVALIDATIONERROR.fields_by_name['validation_error'].enum_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_errors_dot_feed__item__validation__error__pb2._FEEDITEMVALIDATIONERRORENUM_FEEDITEMVALIDATIONERROR
_FEEDITEMVALIDATIONERROR.fields_by_name['description'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_FEEDITEMVALIDATIONERROR.fields_by_name['feed_attribute_ids'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT64VALUE
_FEEDITEMVALIDATIONERROR.fields_by_name['extra_info'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['FeedItem'] = _FEEDITEM
DESCRIPTOR.message_types_by_name['FeedItemAttributeValue'] = _FEEDITEMATTRIBUTEVALUE
DESCRIPTOR.message_types_by_name['FeedItemPlaceholderPolicyInfo'] = _FEEDITEMPLACEHOLDERPOLICYINFO
DESCRIPTOR.message_types_by_name['FeedItemValidationError'] = _FEEDITEMVALIDATIONERROR
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeedItem = _reflection.GeneratedProtocolMessageType('FeedItem', (_message.Message,), dict(
  DESCRIPTOR = _FEEDITEM,
  __module__ = 'google.ads.googleads_v2.proto.resources.feed_item_pb2'
  ,
  __doc__ = """A feed item.
  
  
  Attributes:
      resource_name:
          The resource name of the feed item. Feed item resource names
          have the form:
          ``customers/{customer_id}/feedItems/{feed_id}~{feed_item_id}``
      feed:
          The feed to which this feed item belongs.
      id:
          The ID of this feed item.
      start_date_time:
          Start time in which this feed item is effective and can begin
          serving. The time is in the customer's time zone. The format
          is "YYYY-MM-DD HH:MM:SS". Examples: "2018-03-05 09:15:00" or
          "2018-02-01 14:34:30"
      end_date_time:
          End time in which this feed item is no longer effective and
          will stop serving. The time is in the customer's time zone.
          The format is "YYYY-MM-DD HH:MM:SS". Examples: "2018-03-05
          09:15:00" or "2018-02-01 14:34:30"
      attribute_values:
          The feed item's attribute values.
      geo_targeting_restriction:
          Geo targeting restriction specifies the type of location that
          can be used for targeting.
      url_custom_parameters:
          The list of mappings used to substitute custom parameter tags
          in a ``tracking_url_template``, ``final_urls``, or
          ``mobile_final_urls``.
      status:
          Status of the feed item. This field is read-only.
      policy_infos:
          List of info about a feed item's validation and approval state
          for active feed mappings. There will be an entry in the list
          for each type of feed mapping associated with the feed, e.g. a
          feed with a sitelink and a call feed mapping would cause every
          feed item associated with that feed to have an entry in this
          list for both sitelink and call. This field is read-only.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.FeedItem)
  ))
_sym_db.RegisterMessage(FeedItem)

FeedItemAttributeValue = _reflection.GeneratedProtocolMessageType('FeedItemAttributeValue', (_message.Message,), dict(
  DESCRIPTOR = _FEEDITEMATTRIBUTEVALUE,
  __module__ = 'google.ads.googleads_v2.proto.resources.feed_item_pb2'
  ,
  __doc__ = """A feed item attribute value.
  
  
  Attributes:
      feed_attribute_id:
          Id of the feed attribute for which the value is associated
          with.
      integer_value:
          Int64 value. Should be set if feed\_attribute\_id refers to a
          feed attribute of type INT64.
      boolean_value:
          Bool value. Should be set if feed\_attribute\_id refers to a
          feed attribute of type BOOLEAN.
      string_value:
          String value. Should be set if feed\_attribute\_id refers to a
          feed attribute of type STRING, URL or DATE\_TIME. For STRING
          the maximum length is 1500 characters. For URL the maximum
          length is 2076 characters. For DATE\_TIME the format of the
          string must be the same as start and end time for the feed
          item.
      double_value:
          Double value. Should be set if feed\_attribute\_id refers to a
          feed attribute of type DOUBLE.
      price_value:
          Price value. Should be set if feed\_attribute\_id refers to a
          feed attribute of type PRICE.
      integer_values:
          Repeated int64 value. Should be set if feed\_attribute\_id
          refers to a feed attribute of type INT64\_LIST.
      boolean_values:
          Repeated bool value. Should be set if feed\_attribute\_id
          refers to a feed attribute of type BOOLEAN\_LIST.
      string_values:
          Repeated string value. Should be set if feed\_attribute\_id
          refers to a feed attribute of type STRING\_LIST, URL\_LIST or
          DATE\_TIME\_LIST. For STRING\_LIST and URL\_LIST the total
          size of the list in bytes may not exceed 3000. For
          DATE\_TIME\_LIST the number of elements may not exceed 200.
          For STRING\_LIST the maximum length of each string element is
          1500 characters. For URL\_LIST the maximum length is 2076
          characters. For DATE\_TIME the format of the string must be
          the same as start and end time for the feed item.
      double_values:
          Repeated double value. Should be set if feed\_attribute\_id
          refers to a feed attribute of type DOUBLE\_LIST.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.FeedItemAttributeValue)
  ))
_sym_db.RegisterMessage(FeedItemAttributeValue)

FeedItemPlaceholderPolicyInfo = _reflection.GeneratedProtocolMessageType('FeedItemPlaceholderPolicyInfo', (_message.Message,), dict(
  DESCRIPTOR = _FEEDITEMPLACEHOLDERPOLICYINFO,
  __module__ = 'google.ads.googleads_v2.proto.resources.feed_item_pb2'
  ,
  __doc__ = """Policy, validation, and quality approval info for a feed item for the
  specified placeholder type.
  
  
  Attributes:
      placeholder_type_enum:
          The placeholder type.
      feed_mapping_resource_name:
          The FeedMapping that contains the placeholder type.
      review_status:
          Where the placeholder type is in the review process.
      approval_status:
          The overall approval status of the placeholder type,
          calculated based on the status of its individual policy topic
          entries.
      policy_topic_entries:
          The list of policy findings for the placeholder type.
      validation_status:
          The validation status of the palceholder type.
      validation_errors:
          List of placeholder type validation errors.
      quality_approval_status:
          Placeholder type quality evaluation approval status.
      quality_disapproval_reasons:
          List of placeholder type quality evaluation disapproval
          reasons.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.FeedItemPlaceholderPolicyInfo)
  ))
_sym_db.RegisterMessage(FeedItemPlaceholderPolicyInfo)

FeedItemValidationError = _reflection.GeneratedProtocolMessageType('FeedItemValidationError', (_message.Message,), dict(
  DESCRIPTOR = _FEEDITEMVALIDATIONERROR,
  __module__ = 'google.ads.googleads_v2.proto.resources.feed_item_pb2'
  ,
  __doc__ = """Stores a validation error and the set of offending feed attributes which
  together are responsible for causing a feed item validation error.
  
  
  Attributes:
      validation_error:
          Error code indicating what validation error was triggered. The
          description of the error can be found in the 'description'
          field.
      description:
          The description of the validation error.
      feed_attribute_ids:
          Set of feed attributes in the feed item flagged during
          validation. If empty, no specific feed attributes can be
          associated with the error (e.g. error across the entire feed
          item).
      extra_info:
          Any extra information related to this error which is not
          captured by validation\_error and feed\_attribute\_id (e.g.
          placeholder field IDs when feed\_attribute\_id is not mapped).
          Note that extra\_info is not localized.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.FeedItemValidationError)
  ))
_sym_db.RegisterMessage(FeedItemValidationError)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Copyright 2018 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.




from google.ads.google_ads.v1 import types
from google.ads.google_ads.v1.services import account_budget_proposal_service_client
from google.ads.google_ads.v1.services import account_budget_service_client
from google.ads.google_ads.v1.services import ad_group_ad_label_service_client
from google.ads.google_ads.v1.services import ad_group_ad_service_client
from google.ads.google_ads.v1.services import ad_group_audience_view_service_client
from google.ads.google_ads.v1.services import ad_group_bid_modifier_service_client
from google.ads.google_ads.v1.services import ad_group_criterion_label_service_client
from google.ads.google_ads.v1.services import ad_group_criterion_service_client
from google.ads.google_ads.v1.services import ad_group_criterion_simulation_service_client
from google.ads.google_ads.v1.services import ad_group_extension_setting_service_client
from google.ads.google_ads.v1.services import ad_group_feed_service_client
from google.ads.google_ads.v1.services import ad_group_label_service_client
from google.ads.google_ads.v1.services import ad_group_service_client
from google.ads.google_ads.v1.services import ad_group_simulation_service_client
from google.ads.google_ads.v1.services import ad_parameter_service_client
from google.ads.google_ads.v1.services import ad_schedule_view_service_client
from google.ads.google_ads.v1.services import age_range_view_service_client
from google.ads.google_ads.v1.services import asset_service_client
from google.ads.google_ads.v1.services import bidding_strategy_service_client
from google.ads.google_ads.v1.services import billing_setup_service_client
from google.ads.google_ads.v1.services import campaign_audience_view_service_client
from google.ads.google_ads.v1.services import campaign_bid_modifier_service_client
from google.ads.google_ads.v1.services import campaign_budget_service_client
from google.ads.google_ads.v1.services import campaign_criterion_service_client
from google.ads.google_ads.v1.services import campaign_criterion_simulation_service_client
from google.ads.google_ads.v1.services import campaign_draft_service_client
from google.ads.google_ads.v1.services import campaign_experiment_service_client
from google.ads.google_ads.v1.services import campaign_extension_setting_service_client
from google.ads.google_ads.v1.services import campaign_feed_service_client
from google.ads.google_ads.v1.services import campaign_label_service_client
from google.ads.google_ads.v1.services import campaign_service_client
from google.ads.google_ads.v1.services import campaign_shared_set_service_client
from google.ads.google_ads.v1.services import carrier_constant_service_client
from google.ads.google_ads.v1.services import change_status_service_client
from google.ads.google_ads.v1.services import click_view_service_client
from google.ads.google_ads.v1.services import conversion_action_service_client
from google.ads.google_ads.v1.services import conversion_adjustment_upload_service_client
from google.ads.google_ads.v1.services import conversion_upload_service_client
from google.ads.google_ads.v1.services import customer_client_link_service_client
from google.ads.google_ads.v1.services import customer_client_service_client
from google.ads.google_ads.v1.services import customer_extension_setting_service_client
from google.ads.google_ads.v1.services import customer_feed_service_client
from google.ads.google_ads.v1.services import customer_label_service_client
from google.ads.google_ads.v1.services import customer_manager_link_service_client
from google.ads.google_ads.v1.services import customer_negative_criterion_service_client
from google.ads.google_ads.v1.services import customer_service_client
from google.ads.google_ads.v1.services import custom_interest_service_client
from google.ads.google_ads.v1.services import detail_placement_view_service_client
from google.ads.google_ads.v1.services import display_keyword_view_service_client
from google.ads.google_ads.v1.services import domain_category_service_client
from google.ads.google_ads.v1.services import dynamic_search_ads_search_term_view_service_client
from google.ads.google_ads.v1.services import enums
from google.ads.google_ads.v1.services import expanded_landing_page_view_service_client
from google.ads.google_ads.v1.services import extension_feed_item_service_client
from google.ads.google_ads.v1.services import feed_item_service_client
from google.ads.google_ads.v1.services import feed_item_target_service_client
from google.ads.google_ads.v1.services import feed_mapping_service_client
from google.ads.google_ads.v1.services import feed_placeholder_view_service_client
from google.ads.google_ads.v1.services import feed_service_client
from google.ads.google_ads.v1.services import gender_view_service_client
from google.ads.google_ads.v1.services import geographic_view_service_client
from google.ads.google_ads.v1.services import geo_target_constant_service_client
from google.ads.google_ads.v1.services import google_ads_field_service_client
from google.ads.google_ads.v1.services import google_ads_service_client
from google.ads.google_ads.v1.services import group_placement_view_service_client
from google.ads.google_ads.v1.services import hotel_group_view_service_client
from google.ads.google_ads.v1.services import hotel_performance_view_service_client
from google.ads.google_ads.v1.services import keyword_plan_ad_group_service_client
from google.ads.google_ads.v1.services import keyword_plan_campaign_service_client
from google.ads.google_ads.v1.services import keyword_plan_idea_service_client
from google.ads.google_ads.v1.services import keyword_plan_keyword_service_client
from google.ads.google_ads.v1.services import keyword_plan_negative_keyword_service_client
from google.ads.google_ads.v1.services import keyword_plan_service_client
from google.ads.google_ads.v1.services import keyword_view_service_client
from google.ads.google_ads.v1.services import label_service_client
from google.ads.google_ads.v1.services import landing_page_view_service_client
from google.ads.google_ads.v1.services import language_constant_service_client
from google.ads.google_ads.v1.services import location_view_service_client
from google.ads.google_ads.v1.services import managed_placement_view_service_client
from google.ads.google_ads.v1.services import media_file_service_client
from google.ads.google_ads.v1.services import merchant_center_link_service_client
from google.ads.google_ads.v1.services import mobile_app_category_constant_service_client
from google.ads.google_ads.v1.services import mobile_device_constant_service_client
from google.ads.google_ads.v1.services import mutate_job_service_client
from google.ads.google_ads.v1.services import operating_system_version_constant_service_client
from google.ads.google_ads.v1.services import paid_organic_search_term_view_service_client
from google.ads.google_ads.v1.services import parental_status_view_service_client
from google.ads.google_ads.v1.services import payments_account_service_client
from google.ads.google_ads.v1.services import product_bidding_category_constant_service_client
from google.ads.google_ads.v1.services import product_group_view_service_client
from google.ads.google_ads.v1.services import recommendation_service_client
from google.ads.google_ads.v1.services import remarketing_action_service_client
from google.ads.google_ads.v1.services import search_term_view_service_client
from google.ads.google_ads.v1.services import shared_criterion_service_client
from google.ads.google_ads.v1.services import shared_set_service_client
from google.ads.google_ads.v1.services import shopping_performance_view_service_client
from google.ads.google_ads.v1.services import topic_constant_service_client
from google.ads.google_ads.v1.services import topic_view_service_client
from google.ads.google_ads.v1.services import user_interest_service_client
from google.ads.google_ads.v1.services import user_list_service_client
from google.ads.google_ads.v1.services import video_service_client
from google.ads.google_ads.v1.services.transports import account_budget_proposal_service_grpc_transport
from google.ads.google_ads.v1.services.transports import account_budget_service_grpc_transport
from google.ads.google_ads.v1.services.transports import ad_group_ad_label_service_grpc_transport
from google.ads.google_ads.v1.services.transports import ad_group_ad_service_grpc_transport
from google.ads.google_ads.v1.services.transports import ad_group_audience_view_service_grpc_transport
from google.ads.google_ads.v1.services.transports import ad_group_bid_modifier_service_grpc_transport
from google.ads.google_ads.v1.services.transports import ad_group_criterion_label_service_grpc_transport
from google.ads.google_ads.v1.services.transports import ad_group_criterion_service_grpc_transport
from google.ads.google_ads.v1.services.transports import ad_group_criterion_simulation_service_grpc_transport
from google.ads.google_ads.v1.services.transports import ad_group_extension_setting_service_grpc_transport
from google.ads.google_ads.v1.services.transports import ad_group_feed_service_grpc_transport
from google.ads.google_ads.v1.services.transports import ad_group_label_service_grpc_transport
from google.ads.google_ads.v1.services.transports import ad_group_service_grpc_transport
from google.ads.google_ads.v1.services.transports import ad_group_simulation_service_grpc_transport
from google.ads.google_ads.v1.services.transports import ad_parameter_service_grpc_transport
from google.ads.google_ads.v1.services.transports import ad_schedule_view_service_grpc_transport
from google.ads.google_ads.v1.services.transports import age_range_view_service_grpc_transport
from google.ads.google_ads.v1.services.transports import asset_service_grpc_transport
from google.ads.google_ads.v1.services.transports import bidding_strategy_service_grpc_transport
from google.ads.google_ads.v1.services.transports import billing_setup_service_grpc_transport
from google.ads.google_ads.v1.services.transports import campaign_audience_view_service_grpc_transport
from google.ads.google_ads.v1.services.transports import campaign_bid_modifier_service_grpc_transport
from google.ads.google_ads.v1.services.transports import campaign_budget_service_grpc_transport
from google.ads.google_ads.v1.services.transports import campaign_criterion_service_grpc_transport
from google.ads.google_ads.v1.services.transports import campaign_criterion_simulation_service_grpc_transport
from google.ads.google_ads.v1.services.transports import campaign_draft_service_grpc_transport
from google.ads.google_ads.v1.services.transports import campaign_experiment_service_grpc_transport
from google.ads.google_ads.v1.services.transports import campaign_extension_setting_service_grpc_transport
from google.ads.google_ads.v1.services.transports import campaign_feed_service_grpc_transport
from google.ads.google_ads.v1.services.transports import campaign_label_service_grpc_transport
from google.ads.google_ads.v1.services.transports import campaign_service_grpc_transport
from google.ads.google_ads.v1.services.transports import campaign_shared_set_service_grpc_transport
from google.ads.google_ads.v1.services.transports import carrier_constant_service_grpc_transport
from google.ads.google_ads.v1.services.transports import change_status_service_grpc_transport
from google.ads.google_ads.v1.services.transports import click_view_service_grpc_transport
from google.ads.google_ads.v1.services.transports import conversion_action_service_grpc_transport
from google.ads.google_ads.v1.services.transports import conversion_adjustment_upload_service_grpc_transport
from google.ads.google_ads.v1.services.transports import conversion_upload_service_grpc_transport
from google.ads.google_ads.v1.services.transports import customer_client_link_service_grpc_transport
from google.ads.google_ads.v1.services.transports import customer_client_service_grpc_transport
from google.ads.google_ads.v1.services.transports import customer_extension_setting_service_grpc_transport
from google.ads.google_ads.v1.services.transports import customer_feed_service_grpc_transport
from google.ads.google_ads.v1.services.transports import customer_label_service_grpc_transport
from google.ads.google_ads.v1.services.transports import customer_manager_link_service_grpc_transport
from google.ads.google_ads.v1.services.transports import customer_negative_criterion_service_grpc_transport
from google.ads.google_ads.v1.services.transports import customer_service_grpc_transport
from google.ads.google_ads.v1.services.transports import custom_interest_service_grpc_transport
from google.ads.google_ads.v1.services.transports import detail_placement_view_service_grpc_transport
from google.ads.google_ads.v1.services.transports import display_keyword_view_service_grpc_transport
from google.ads.google_ads.v1.services.transports import domain_category_service_grpc_transport
from google.ads.google_ads.v1.services.transports import dynamic_search_ads_search_term_view_service_grpc_transport
from google.ads.google_ads.v1.services.transports import expanded_landing_page_view_service_grpc_transport
from google.ads.google_ads.v1.services.transports import extension_feed_item_service_grpc_transport
from google.ads.google_ads.v1.services.transports import feed_item_service_grpc_transport
from google.ads.google_ads.v1.services.transports import feed_item_target_service_grpc_transport
from google.ads.google_ads.v1.services.transports import feed_mapping_service_grpc_transport
from google.ads.google_ads.v1.services.transports import feed_placeholder_view_service_grpc_transport
from google.ads.google_ads.v1.services.transports import feed_service_grpc_transport
from google.ads.google_ads.v1.services.transports import gender_view_service_grpc_transport
from google.ads.google_ads.v1.services.transports import geographic_view_service_grpc_transport
from google.ads.google_ads.v1.services.transports import geo_target_constant_service_grpc_transport
from google.ads.google_ads.v1.services.transports import google_ads_field_service_grpc_transport
from google.ads.google_ads.v1.services.transports import google_ads_service_grpc_transport
from google.ads.google_ads.v1.services.transports import group_placement_view_service_grpc_transport
from google.ads.google_ads.v1.services.transports import hotel_group_view_service_grpc_transport
from google.ads.google_ads.v1.services.transports import hotel_performance_view_service_grpc_transport
from google.ads.google_ads.v1.services.transports import keyword_plan_ad_group_service_grpc_transport
from google.ads.google_ads.v1.services.transports import keyword_plan_campaign_service_grpc_transport
from google.ads.google_ads.v1.services.transports import keyword_plan_idea_service_grpc_transport
from google.ads.google_ads.v1.services.transports import keyword_plan_keyword_service_grpc_transport
from google.ads.google_ads.v1.services.transports import keyword_plan_negative_keyword_service_grpc_transport
from google.ads.google_ads.v1.services.transports import keyword_plan_service_grpc_transport
from google.ads.google_ads.v1.services.transports import keyword_view_service_grpc_transport
from google.ads.google_ads.v1.services.transports import label_service_grpc_transport
from google.ads.google_ads.v1.services.transports import landing_page_view_service_grpc_transport
from google.ads.google_ads.v1.services.transports import language_constant_service_grpc_transport
from google.ads.google_ads.v1.services.transports import location_view_service_grpc_transport
from google.ads.google_ads.v1.services.transports import managed_placement_view_service_grpc_transport
from google.ads.google_ads.v1.services.transports import media_file_service_grpc_transport
from google.ads.google_ads.v1.services.transports import merchant_center_link_service_grpc_transport
from google.ads.google_ads.v1.services.transports import mobile_app_category_constant_service_grpc_transport
from google.ads.google_ads.v1.services.transports import mobile_device_constant_service_grpc_transport
from google.ads.google_ads.v1.services.transports import mutate_job_service_grpc_transport
from google.ads.google_ads.v1.services.transports import operating_system_version_constant_service_grpc_transport
from google.ads.google_ads.v1.services.transports import paid_organic_search_term_view_service_grpc_transport
from google.ads.google_ads.v1.services.transports import parental_status_view_service_grpc_transport
from google.ads.google_ads.v1.services.transports import payments_account_service_grpc_transport
from google.ads.google_ads.v1.services.transports import product_bidding_category_constant_service_grpc_transport
from google.ads.google_ads.v1.services.transports import product_group_view_service_grpc_transport
from google.ads.google_ads.v1.services.transports import recommendation_service_grpc_transport
from google.ads.google_ads.v1.services.transports import remarketing_action_service_grpc_transport
from google.ads.google_ads.v1.services.transports import search_term_view_service_grpc_transport
from google.ads.google_ads.v1.services.transports import shared_criterion_service_grpc_transport
from google.ads.google_ads.v1.services.transports import shared_set_service_grpc_transport
from google.ads.google_ads.v1.services.transports import shopping_performance_view_service_grpc_transport
from google.ads.google_ads.v1.services.transports import topic_constant_service_grpc_transport
from google.ads.google_ads.v1.services.transports import topic_view_service_grpc_transport
from google.ads.google_ads.v1.services.transports import user_interest_service_grpc_transport
from google.ads.google_ads.v1.services.transports import user_list_service_grpc_transport
from google.ads.google_ads.v1.services.transports import video_service_grpc_transport


class AccountBudgetProposalServiceClient(
    account_budget_proposal_service_client.AccountBudgetProposalServiceClient):
    __doc__ = account_budget_proposal_service_client.AccountBudgetProposalServiceClient.__doc__
    enums = enums


class AccountBudgetServiceClient(
    account_budget_service_client.AccountBudgetServiceClient):
    __doc__ = account_budget_service_client.AccountBudgetServiceClient.__doc__
    enums = enums


class AdGroupAdLabelServiceClient(
    ad_group_ad_label_service_client.AdGroupAdLabelServiceClient):
    __doc__ = ad_group_ad_label_service_client.AdGroupAdLabelServiceClient.__doc__
    enums = enums


class AdGroupAdServiceClient(
    ad_group_ad_service_client.AdGroupAdServiceClient):
    __doc__ = ad_group_ad_service_client.AdGroupAdServiceClient.__doc__
    enums = enums


class AdGroupAudienceViewServiceClient(
    ad_group_audience_view_service_client.AdGroupAudienceViewServiceClient):
    __doc__ = ad_group_audience_view_service_client.AdGroupAudienceViewServiceClient.__doc__
    enums = enums


class AdGroupBidModifierServiceClient(
    ad_group_bid_modifier_service_client.AdGroupBidModifierServiceClient):
    __doc__ = ad_group_bid_modifier_service_client.AdGroupBidModifierServiceClient.__doc__
    enums = enums


class AdGroupCriterionLabelServiceClient(
    ad_group_criterion_label_service_client.AdGroupCriterionLabelServiceClient):
    __doc__ = ad_group_criterion_label_service_client.AdGroupCriterionLabelServiceClient.__doc__
    enums = enums


class AdGroupCriterionServiceClient(
    ad_group_criterion_service_client.AdGroupCriterionServiceClient):
    __doc__ = ad_group_criterion_service_client.AdGroupCriterionServiceClient.__doc__
    enums = enums


class AdGroupCriterionSimulationServiceClient(
    ad_group_criterion_simulation_service_client.AdGroupCriterionSimulationServiceClient):
    __doc__ = ad_group_criterion_simulation_service_client.AdGroupCriterionSimulationServiceClient.__doc__
    enums = enums


class AdGroupExtensionSettingServiceClient(
    ad_group_extension_setting_service_client.AdGroupExtensionSettingServiceClient):
    __doc__ = ad_group_extension_setting_service_client.AdGroupExtensionSettingServiceClient.__doc__
    enums = enums


class AdGroupFeedServiceClient(
    ad_group_feed_service_client.AdGroupFeedServiceClient):
    __doc__ = ad_group_feed_service_client.AdGroupFeedServiceClient.__doc__
    enums = enums


class AdGroupLabelServiceClient(
    ad_group_label_service_client.AdGroupLabelServiceClient):
    __doc__ = ad_group_label_service_client.AdGroupLabelServiceClient.__doc__
    enums = enums


class AdGroupServiceClient(
    ad_group_service_client.AdGroupServiceClient):
    __doc__ = ad_group_service_client.AdGroupServiceClient.__doc__
    enums = enums


class AdGroupSimulationServiceClient(
    ad_group_simulation_service_client.AdGroupSimulationServiceClient):
    __doc__ = ad_group_simulation_service_client.AdGroupSimulationServiceClient.__doc__
    enums = enums


class AdParameterServiceClient(
    ad_parameter_service_client.AdParameterServiceClient):
    __doc__ = ad_parameter_service_client.AdParameterServiceClient.__doc__
    enums = enums


class AdScheduleViewServiceClient(
    ad_schedule_view_service_client.AdScheduleViewServiceClient):
    __doc__ = ad_schedule_view_service_client.AdScheduleViewServiceClient.__doc__
    enums = enums


class AgeRangeViewServiceClient(
    age_range_view_service_client.AgeRangeViewServiceClient):
    __doc__ = age_range_view_service_client.AgeRangeViewServiceClient.__doc__
    enums = enums


class AssetServiceClient(
    asset_service_client.AssetServiceClient):
    __doc__ = asset_service_client.AssetServiceClient.__doc__
    enums = enums


class BiddingStrategyServiceClient(
    bidding_strategy_service_client.BiddingStrategyServiceClient):
    __doc__ = bidding_strategy_service_client.BiddingStrategyServiceClient.__doc__
    enums = enums


class BillingSetupServiceClient(
    billing_setup_service_client.BillingSetupServiceClient):
    __doc__ = billing_setup_service_client.BillingSetupServiceClient.__doc__
    enums = enums


class CampaignAudienceViewServiceClient(
    campaign_audience_view_service_client.CampaignAudienceViewServiceClient):
    __doc__ = campaign_audience_view_service_client.CampaignAudienceViewServiceClient.__doc__
    enums = enums


class CampaignBidModifierServiceClient(
    campaign_bid_modifier_service_client.CampaignBidModifierServiceClient):
    __doc__ = campaign_bid_modifier_service_client.CampaignBidModifierServiceClient.__doc__
    enums = enums


class CampaignBudgetServiceClient(
    campaign_budget_service_client.CampaignBudgetServiceClient):
    __doc__ = campaign_budget_service_client.CampaignBudgetServiceClient.__doc__
    enums = enums


class CampaignCriterionServiceClient(
    campaign_criterion_service_client.CampaignCriterionServiceClient):
    __doc__ = campaign_criterion_service_client.CampaignCriterionServiceClient.__doc__
    enums = enums


class CampaignCriterionSimulationServiceClient(
    campaign_criterion_simulation_service_client.CampaignCriterionSimulationServiceClient):
    __doc__ = campaign_criterion_simulation_service_client.CampaignCriterionSimulationServiceClient.__doc__
    enums = enums


class CampaignDraftServiceClient(
    campaign_draft_service_client.CampaignDraftServiceClient):
    __doc__ = campaign_draft_service_client.CampaignDraftServiceClient.__doc__
    enums = enums


class CampaignExperimentServiceClient(
    campaign_experiment_service_client.CampaignExperimentServiceClient):
    __doc__ = campaign_experiment_service_client.CampaignExperimentServiceClient.__doc__
    enums = enums


class CampaignExtensionSettingServiceClient(
    campaign_extension_setting_service_client.CampaignExtensionSettingServiceClient):
    __doc__ = campaign_extension_setting_service_client.CampaignExtensionSettingServiceClient.__doc__
    enums = enums


class CampaignFeedServiceClient(
    campaign_feed_service_client.CampaignFeedServiceClient):
    __doc__ = campaign_feed_service_client.CampaignFeedServiceClient.__doc__
    enums = enums


class CampaignLabelServiceClient(
    campaign_label_service_client.CampaignLabelServiceClient):
    __doc__ = campaign_label_service_client.CampaignLabelServiceClient.__doc__
    enums = enums


class CampaignServiceClient(
    campaign_service_client.CampaignServiceClient):
    __doc__ = campaign_service_client.CampaignServiceClient.__doc__
    enums = enums


class CampaignSharedSetServiceClient(
    campaign_shared_set_service_client.CampaignSharedSetServiceClient):
    __doc__ = campaign_shared_set_service_client.CampaignSharedSetServiceClient.__doc__
    enums = enums


class CarrierConstantServiceClient(
    carrier_constant_service_client.CarrierConstantServiceClient):
    __doc__ = carrier_constant_service_client.CarrierConstantServiceClient.__doc__
    enums = enums


class ChangeStatusServiceClient(
    change_status_service_client.ChangeStatusServiceClient):
    __doc__ = change_status_service_client.ChangeStatusServiceClient.__doc__
    enums = enums


class ClickViewServiceClient(
    click_view_service_client.ClickViewServiceClient):
    __doc__ = click_view_service_client.ClickViewServiceClient.__doc__
    enums = enums


class ConversionActionServiceClient(
    conversion_action_service_client.ConversionActionServiceClient):
    __doc__ = conversion_action_service_client.ConversionActionServiceClient.__doc__
    enums = enums


class ConversionAdjustmentUploadServiceClient(
    conversion_adjustment_upload_service_client.ConversionAdjustmentUploadServiceClient):
    __doc__ = conversion_adjustment_upload_service_client.ConversionAdjustmentUploadServiceClient.__doc__
    enums = enums


class ConversionUploadServiceClient(
    conversion_upload_service_client.ConversionUploadServiceClient):
    __doc__ = conversion_upload_service_client.ConversionUploadServiceClient.__doc__
    enums = enums


class CustomerClientLinkServiceClient(
    customer_client_link_service_client.CustomerClientLinkServiceClient):
    __doc__ = customer_client_link_service_client.CustomerClientLinkServiceClient.__doc__
    enums = enums


class CustomerClientServiceClient(
    customer_client_service_client.CustomerClientServiceClient):
    __doc__ = customer_client_service_client.CustomerClientServiceClient.__doc__
    enums = enums


class CustomerExtensionSettingServiceClient(
    customer_extension_setting_service_client.CustomerExtensionSettingServiceClient):
    __doc__ = customer_extension_setting_service_client.CustomerExtensionSettingServiceClient.__doc__
    enums = enums


class CustomerFeedServiceClient(
    customer_feed_service_client.CustomerFeedServiceClient):
    __doc__ = customer_feed_service_client.CustomerFeedServiceClient.__doc__
    enums = enums


class CustomerLabelServiceClient(
    customer_label_service_client.CustomerLabelServiceClient):
    __doc__ = customer_label_service_client.CustomerLabelServiceClient.__doc__
    enums = enums


class CustomerManagerLinkServiceClient(
    customer_manager_link_service_client.CustomerManagerLinkServiceClient):
    __doc__ = customer_manager_link_service_client.CustomerManagerLinkServiceClient.__doc__
    enums = enums


class CustomerNegativeCriterionServiceClient(
    customer_negative_criterion_service_client.CustomerNegativeCriterionServiceClient):
    __doc__ = customer_negative_criterion_service_client.CustomerNegativeCriterionServiceClient.__doc__
    enums = enums


class CustomerServiceClient(
    customer_service_client.CustomerServiceClient):
    __doc__ = customer_service_client.CustomerServiceClient.__doc__
    enums = enums


class CustomInterestServiceClient(
    custom_interest_service_client.CustomInterestServiceClient):
    __doc__ = custom_interest_service_client.CustomInterestServiceClient.__doc__
    enums = enums


class DetailPlacementViewServiceClient(
    detail_placement_view_service_client.DetailPlacementViewServiceClient):
    __doc__ = detail_placement_view_service_client.DetailPlacementViewServiceClient.__doc__
    enums = enums


class DisplayKeywordViewServiceClient(
    display_keyword_view_service_client.DisplayKeywordViewServiceClient):
    __doc__ = display_keyword_view_service_client.DisplayKeywordViewServiceClient.__doc__
    enums = enums


class DomainCategoryServiceClient(
    domain_category_service_client.DomainCategoryServiceClient):
    __doc__ = domain_category_service_client.DomainCategoryServiceClient.__doc__
    enums = enums


class DynamicSearchAdsSearchTermViewServiceClient(
    dynamic_search_ads_search_term_view_service_client.DynamicSearchAdsSearchTermViewServiceClient):
    __doc__ = dynamic_search_ads_search_term_view_service_client.DynamicSearchAdsSearchTermViewServiceClient.__doc__
    enums = enums


class ExpandedLandingPageViewServiceClient(
    expanded_landing_page_view_service_client.ExpandedLandingPageViewServiceClient):
    __doc__ = expanded_landing_page_view_service_client.ExpandedLandingPageViewServiceClient.__doc__
    enums = enums


class ExtensionFeedItemServiceClient(
    extension_feed_item_service_client.ExtensionFeedItemServiceClient):
    __doc__ = extension_feed_item_service_client.ExtensionFeedItemServiceClient.__doc__
    enums = enums


class FeedItemServiceClient(
    feed_item_service_client.FeedItemServiceClient):
    __doc__ = feed_item_service_client.FeedItemServiceClient.__doc__
    enums = enums


class FeedItemTargetServiceClient(
    feed_item_target_service_client.FeedItemTargetServiceClient):
    __doc__ = feed_item_target_service_client.FeedItemTargetServiceClient.__doc__
    enums = enums


class FeedMappingServiceClient(
    feed_mapping_service_client.FeedMappingServiceClient):
    __doc__ = feed_mapping_service_client.FeedMappingServiceClient.__doc__
    enums = enums


class FeedPlaceholderViewServiceClient(
    feed_placeholder_view_service_client.FeedPlaceholderViewServiceClient):
    __doc__ = feed_placeholder_view_service_client.FeedPlaceholderViewServiceClient.__doc__
    enums = enums


class FeedServiceClient(
    feed_service_client.FeedServiceClient):
    __doc__ = feed_service_client.FeedServiceClient.__doc__
    enums = enums


class GenderViewServiceClient(
    gender_view_service_client.GenderViewServiceClient):
    __doc__ = gender_view_service_client.GenderViewServiceClient.__doc__
    enums = enums


class GeographicViewServiceClient(
    geographic_view_service_client.GeographicViewServiceClient):
    __doc__ = geographic_view_service_client.GeographicViewServiceClient.__doc__
    enums = enums


class GeoTargetConstantServiceClient(
    geo_target_constant_service_client.GeoTargetConstantServiceClient):
    __doc__ = geo_target_constant_service_client.GeoTargetConstantServiceClient.__doc__
    enums = enums


class GoogleAdsFieldServiceClient(
    google_ads_field_service_client.GoogleAdsFieldServiceClient):
    __doc__ = google_ads_field_service_client.GoogleAdsFieldServiceClient.__doc__
    enums = enums


class GoogleAdsServiceClient(
    google_ads_service_client.GoogleAdsServiceClient):
    __doc__ = google_ads_service_client.GoogleAdsServiceClient.__doc__
    enums = enums


class GroupPlacementViewServiceClient(
    group_placement_view_service_client.GroupPlacementViewServiceClient):
    __doc__ = group_placement_view_service_client.GroupPlacementViewServiceClient.__doc__
    enums = enums


class HotelGroupViewServiceClient(
    hotel_group_view_service_client.HotelGroupViewServiceClient):
    __doc__ = hotel_group_view_service_client.HotelGroupViewServiceClient.__doc__
    enums = enums


class HotelPerformanceViewServiceClient(
    hotel_performance_view_service_client.HotelPerformanceViewServiceClient):
    __doc__ = hotel_performance_view_service_client.HotelPerformanceViewServiceClient.__doc__
    enums = enums


class KeywordPlanAdGroupServiceClient(
    keyword_plan_ad_group_service_client.KeywordPlanAdGroupServiceClient):
    __doc__ = keyword_plan_ad_group_service_client.KeywordPlanAdGroupServiceClient.__doc__
    enums = enums


class KeywordPlanCampaignServiceClient(
    keyword_plan_campaign_service_client.KeywordPlanCampaignServiceClient):
    __doc__ = keyword_plan_campaign_service_client.KeywordPlanCampaignServiceClient.__doc__
    enums = enums


class KeywordPlanIdeaServiceClient(
    keyword_plan_idea_service_client.KeywordPlanIdeaServiceClient):
    __doc__ = keyword_plan_idea_service_client.KeywordPlanIdeaServiceClient.__doc__
    enums = enums


class KeywordPlanKeywordServiceClient(
    keyword_plan_keyword_service_client.KeywordPlanKeywordServiceClient):
    __doc__ = keyword_plan_keyword_service_client.KeywordPlanKeywordServiceClient.__doc__
    enums = enums


class KeywordPlanNegativeKeywordServiceClient(
    keyword_plan_negative_keyword_service_client.KeywordPlanNegativeKeywordServiceClient):
    __doc__ = keyword_plan_negative_keyword_service_client.KeywordPlanNegativeKeywordServiceClient.__doc__
    enums = enums


class KeywordPlanServiceClient(
    keyword_plan_service_client.KeywordPlanServiceClient):
    __doc__ = keyword_plan_service_client.KeywordPlanServiceClient.__doc__
    enums = enums


class KeywordViewServiceClient(
    keyword_view_service_client.KeywordViewServiceClient):
    __doc__ = keyword_view_service_client.KeywordViewServiceClient.__doc__
    enums = enums


class LabelServiceClient(
    label_service_client.LabelServiceClient):
    __doc__ = label_service_client.LabelServiceClient.__doc__
    enums = enums


class LandingPageViewServiceClient(
    landing_page_view_service_client.LandingPageViewServiceClient):
    __doc__ = landing_page_view_service_client.LandingPageViewServiceClient.__doc__
    enums = enums


class LanguageConstantServiceClient(
    language_constant_service_client.LanguageConstantServiceClient):
    __doc__ = language_constant_service_client.LanguageConstantServiceClient.__doc__
    enums = enums


class LocationViewServiceClient(
    location_view_service_client.LocationViewServiceClient):
    __doc__ = location_view_service_client.LocationViewServiceClient.__doc__
    enums = enums


class ManagedPlacementViewServiceClient(
    managed_placement_view_service_client.ManagedPlacementViewServiceClient):
    __doc__ = managed_placement_view_service_client.ManagedPlacementViewServiceClient.__doc__
    enums = enums


class MediaFileServiceClient(
    media_file_service_client.MediaFileServiceClient):
    __doc__ = media_file_service_client.MediaFileServiceClient.__doc__
    enums = enums


class MerchantCenterLinkServiceClient(
    merchant_center_link_service_client.MerchantCenterLinkServiceClient):
    __doc__ = merchant_center_link_service_client.MerchantCenterLinkServiceClient.__doc__
    enums = enums


class MobileAppCategoryConstantServiceClient(
    mobile_app_category_constant_service_client.MobileAppCategoryConstantServiceClient):
    __doc__ = mobile_app_category_constant_service_client.MobileAppCategoryConstantServiceClient.__doc__
    enums = enums


class MobileDeviceConstantServiceClient(
    mobile_device_constant_service_client.MobileDeviceConstantServiceClient):
    __doc__ = mobile_device_constant_service_client.MobileDeviceConstantServiceClient.__doc__
    enums = enums


class MutateJobServiceClient(
    mutate_job_service_client.MutateJobServiceClient):
    __doc__ = mutate_job_service_client.MutateJobServiceClient.__doc__
    enums = enums


class OperatingSystemVersionConstantServiceClient(
    operating_system_version_constant_service_client.OperatingSystemVersionConstantServiceClient):
    __doc__ = operating_system_version_constant_service_client.OperatingSystemVersionConstantServiceClient.__doc__
    enums = enums


class PaidOrganicSearchTermViewServiceClient(
    paid_organic_search_term_view_service_client.PaidOrganicSearchTermViewServiceClient):
    __doc__ = paid_organic_search_term_view_service_client.PaidOrganicSearchTermViewServiceClient.__doc__
    enums = enums


class ParentalStatusViewServiceClient(
    parental_status_view_service_client.ParentalStatusViewServiceClient):
    __doc__ = parental_status_view_service_client.ParentalStatusViewServiceClient.__doc__
    enums = enums


class PaymentsAccountServiceClient(
    payments_account_service_client.PaymentsAccountServiceClient):
    __doc__ = payments_account_service_client.PaymentsAccountServiceClient.__doc__
    enums = enums


class ProductBiddingCategoryConstantServiceClient(
    product_bidding_category_constant_service_client.ProductBiddingCategoryConstantServiceClient):
    __doc__ = product_bidding_category_constant_service_client.ProductBiddingCategoryConstantServiceClient.__doc__
    enums = enums


class ProductGroupViewServiceClient(
    product_group_view_service_client.ProductGroupViewServiceClient):
    __doc__ = product_group_view_service_client.ProductGroupViewServiceClient.__doc__
    enums = enums


class RecommendationServiceClient(
    recommendation_service_client.RecommendationServiceClient):
    __doc__ = recommendation_service_client.RecommendationServiceClient.__doc__
    enums = enums


class RemarketingActionServiceClient(
    remarketing_action_service_client.RemarketingActionServiceClient):
    __doc__ = remarketing_action_service_client.RemarketingActionServiceClient.__doc__
    enums = enums


class SearchTermViewServiceClient(
    search_term_view_service_client.SearchTermViewServiceClient):
    __doc__ = search_term_view_service_client.SearchTermViewServiceClient.__doc__
    enums = enums


class SharedCriterionServiceClient(
    shared_criterion_service_client.SharedCriterionServiceClient):
    __doc__ = shared_criterion_service_client.SharedCriterionServiceClient.__doc__
    enums = enums


class SharedSetServiceClient(
    shared_set_service_client.SharedSetServiceClient):
    __doc__ = shared_set_service_client.SharedSetServiceClient.__doc__
    enums = enums


class ShoppingPerformanceViewServiceClient(
    shopping_performance_view_service_client.ShoppingPerformanceViewServiceClient):
    __doc__ = shopping_performance_view_service_client.ShoppingPerformanceViewServiceClient.__doc__
    enums = enums


class TopicConstantServiceClient(
    topic_constant_service_client.TopicConstantServiceClient):
    __doc__ = topic_constant_service_client.TopicConstantServiceClient.__doc__
    enums = enums


class TopicViewServiceClient(
    topic_view_service_client.TopicViewServiceClient):
    __doc__ = topic_view_service_client.TopicViewServiceClient.__doc__
    enums = enums


class UserInterestServiceClient(
    user_interest_service_client.UserInterestServiceClient):
    __doc__ = user_interest_service_client.UserInterestServiceClient.__doc__
    enums = enums


class UserListServiceClient(
    user_list_service_client.UserListServiceClient):
    __doc__ = user_list_service_client.UserListServiceClient.__doc__
    enums = enums


class VideoServiceClient(
    video_service_client.VideoServiceClient):
    __doc__ = video_service_client.VideoServiceClient.__doc__
    enums = enums


class AccountBudgetProposalServiceGrpcTransport(
    account_budget_proposal_service_grpc_transport.AccountBudgetProposalServiceGrpcTransport):
    __doc__ = account_budget_proposal_service_grpc_transport.AccountBudgetProposalServiceGrpcTransport.__doc__


class AccountBudgetServiceGrpcTransport(
    account_budget_service_grpc_transport.AccountBudgetServiceGrpcTransport):
    __doc__ = account_budget_service_grpc_transport.AccountBudgetServiceGrpcTransport.__doc__


class AdGroupAdLabelServiceGrpcTransport(
    ad_group_ad_label_service_grpc_transport.AdGroupAdLabelServiceGrpcTransport):
    __doc__ = ad_group_ad_label_service_grpc_transport.AdGroupAdLabelServiceGrpcTransport.__doc__


class AdGroupAdServiceGrpcTransport(
    ad_group_ad_service_grpc_transport.AdGroupAdServiceGrpcTransport):
    __doc__ = ad_group_ad_service_grpc_transport.AdGroupAdServiceGrpcTransport.__doc__


class AdGroupAudienceViewServiceGrpcTransport(
    ad_group_audience_view_service_grpc_transport.AdGroupAudienceViewServiceGrpcTransport):
    __doc__ = ad_group_audience_view_service_grpc_transport.AdGroupAudienceViewServiceGrpcTransport.__doc__


class AdGroupBidModifierServiceGrpcTransport(
    ad_group_bid_modifier_service_grpc_transport.AdGroupBidModifierServiceGrpcTransport):
    __doc__ = ad_group_bid_modifier_service_grpc_transport.AdGroupBidModifierServiceGrpcTransport.__doc__


class AdGroupCriterionLabelServiceGrpcTransport(
    ad_group_criterion_label_service_grpc_transport.AdGroupCriterionLabelServiceGrpcTransport):
    __doc__ = ad_group_criterion_label_service_grpc_transport.AdGroupCriterionLabelServiceGrpcTransport.__doc__


class AdGroupCriterionServiceGrpcTransport(
    ad_group_criterion_service_grpc_transport.AdGroupCriterionServiceGrpcTransport):
    __doc__ = ad_group_criterion_service_grpc_transport.AdGroupCriterionServiceGrpcTransport.__doc__


class AdGroupCriterionSimulationServiceGrpcTransport(
    ad_group_criterion_simulation_service_grpc_transport.AdGroupCriterionSimulationServiceGrpcTransport):
    __doc__ = ad_group_criterion_simulation_service_grpc_transport.AdGroupCriterionSimulationServiceGrpcTransport.__doc__


class AdGroupExtensionSettingServiceGrpcTransport(
    ad_group_extension_setting_service_grpc_transport.AdGroupExtensionSettingServiceGrpcTransport):
    __doc__ = ad_group_extension_setting_service_grpc_transport.AdGroupExtensionSettingServiceGrpcTransport.__doc__


class AdGroupFeedServiceGrpcTransport(
    ad_group_feed_service_grpc_transport.AdGroupFeedServiceGrpcTransport):
    __doc__ = ad_group_feed_service_grpc_transport.AdGroupFeedServiceGrpcTransport.__doc__


class AdGroupLabelServiceGrpcTransport(
    ad_group_label_service_grpc_transport.AdGroupLabelServiceGrpcTransport):
    __doc__ = ad_group_label_service_grpc_transport.AdGroupLabelServiceGrpcTransport.__doc__


class AdGroupServiceGrpcTransport(
    ad_group_service_grpc_transport.AdGroupServiceGrpcTransport):
    __doc__ = ad_group_service_grpc_transport.AdGroupServiceGrpcTransport.__doc__


class AdGroupSimulationServiceGrpcTransport(
    ad_group_simulation_service_grpc_transport.AdGroupSimulationServiceGrpcTransport):
    __doc__ = ad_group_simulation_service_grpc_transport.AdGroupSimulationServiceGrpcTransport.__doc__


class AdParameterServiceGrpcTransport(
    ad_parameter_service_grpc_transport.AdParameterServiceGrpcTransport):
    __doc__ = ad_parameter_service_grpc_transport.AdParameterServiceGrpcTransport.__doc__


class AdScheduleViewServiceGrpcTransport(
    ad_schedule_view_service_grpc_transport.AdScheduleViewServiceGrpcTransport):
    __doc__ = ad_schedule_view_service_grpc_transport.AdScheduleViewServiceGrpcTransport.__doc__


class AgeRangeViewServiceGrpcTransport(
    age_range_view_service_grpc_transport.AgeRangeViewServiceGrpcTransport):
    __doc__ = age_range_view_service_grpc_transport.AgeRangeViewServiceGrpcTransport.__doc__


class AssetServiceGrpcTransport(
    asset_service_grpc_transport.AssetServiceGrpcTransport):
    __doc__ = asset_service_grpc_transport.AssetServiceGrpcTransport.__doc__


class BiddingStrategyServiceGrpcTransport(
    bidding_strategy_service_grpc_transport.BiddingStrategyServiceGrpcTransport):
    __doc__ = bidding_strategy_service_grpc_transport.BiddingStrategyServiceGrpcTransport.__doc__


class BillingSetupServiceGrpcTransport(
    billing_setup_service_grpc_transport.BillingSetupServiceGrpcTransport):
    __doc__ = billing_setup_service_grpc_transport.BillingSetupServiceGrpcTransport.__doc__


class CampaignAudienceViewServiceGrpcTransport(
    campaign_audience_view_service_grpc_transport.CampaignAudienceViewServiceGrpcTransport):
    __doc__ = campaign_audience_view_service_grpc_transport.CampaignAudienceViewServiceGrpcTransport.__doc__


class CampaignBidModifierServiceGrpcTransport(
    campaign_bid_modifier_service_grpc_transport.CampaignBidModifierServiceGrpcTransport):
    __doc__ = campaign_bid_modifier_service_grpc_transport.CampaignBidModifierServiceGrpcTransport.__doc__


class CampaignBudgetServiceGrpcTransport(
    campaign_budget_service_grpc_transport.CampaignBudgetServiceGrpcTransport):
    __doc__ = campaign_budget_service_grpc_transport.CampaignBudgetServiceGrpcTransport.__doc__


class CampaignCriterionServiceGrpcTransport(
    campaign_criterion_service_grpc_transport.CampaignCriterionServiceGrpcTransport):
    __doc__ = campaign_criterion_service_grpc_transport.CampaignCriterionServiceGrpcTransport.__doc__


class CampaignCriterionSimulationServiceGrpcTransport(
    campaign_criterion_simulation_service_grpc_transport.CampaignCriterionSimulationServiceGrpcTransport):
    __doc__ = campaign_criterion_simulation_service_grpc_transport.CampaignCriterionSimulationServiceGrpcTransport.__doc__


class CampaignDraftServiceGrpcTransport(
    campaign_draft_service_grpc_transport.CampaignDraftServiceGrpcTransport):
    __doc__ = campaign_draft_service_grpc_transport.CampaignDraftServiceGrpcTransport.__doc__


class CampaignExperimentServiceGrpcTransport(
    campaign_experiment_service_grpc_transport.CampaignExperimentServiceGrpcTransport):
    __doc__ = campaign_experiment_service_grpc_transport.CampaignExperimentServiceGrpcTransport.__doc__


class CampaignExtensionSettingServiceGrpcTransport(
    campaign_extension_setting_service_grpc_transport.CampaignExtensionSettingServiceGrpcTransport):
    __doc__ = campaign_extension_setting_service_grpc_transport.CampaignExtensionSettingServiceGrpcTransport.__doc__


class CampaignFeedServiceGrpcTransport(
    campaign_feed_service_grpc_transport.CampaignFeedServiceGrpcTransport):
    __doc__ = campaign_feed_service_grpc_transport.CampaignFeedServiceGrpcTransport.__doc__


class CampaignLabelServiceGrpcTransport(
    campaign_label_service_grpc_transport.CampaignLabelServiceGrpcTransport):
    __doc__ = campaign_label_service_grpc_transport.CampaignLabelServiceGrpcTransport.__doc__


class CampaignServiceGrpcTransport(
    campaign_service_grpc_transport.CampaignServiceGrpcTransport):
    __doc__ = campaign_service_grpc_transport.CampaignServiceGrpcTransport.__doc__


class CampaignSharedSetServiceGrpcTransport(
    campaign_shared_set_service_grpc_transport.CampaignSharedSetServiceGrpcTransport):
    __doc__ = campaign_shared_set_service_grpc_transport.CampaignSharedSetServiceGrpcTransport.__doc__


class CarrierConstantServiceGrpcTransport(
    carrier_constant_service_grpc_transport.CarrierConstantServiceGrpcTransport):
    __doc__ = carrier_constant_service_grpc_transport.CarrierConstantServiceGrpcTransport.__doc__


class ChangeStatusServiceGrpcTransport(
    change_status_service_grpc_transport.ChangeStatusServiceGrpcTransport):
    __doc__ = change_status_service_grpc_transport.ChangeStatusServiceGrpcTransport.__doc__


class ClickViewServiceGrpcTransport(
    click_view_service_grpc_transport.ClickViewServiceGrpcTransport):
    __doc__ = click_view_service_grpc_transport.ClickViewServiceGrpcTransport.__doc__


class ConversionActionServiceGrpcTransport(
    conversion_action_service_grpc_transport.ConversionActionServiceGrpcTransport):
    __doc__ = conversion_action_service_grpc_transport.ConversionActionServiceGrpcTransport.__doc__


class ConversionAdjustmentUploadServiceGrpcTransport(
    conversion_adjustment_upload_service_grpc_transport.ConversionAdjustmentUploadServiceGrpcTransport):
    __doc__ = conversion_adjustment_upload_service_grpc_transport.ConversionAdjustmentUploadServiceGrpcTransport.__doc__


class ConversionUploadServiceGrpcTransport(
    conversion_upload_service_grpc_transport.ConversionUploadServiceGrpcTransport):
    __doc__ = conversion_upload_service_grpc_transport.ConversionUploadServiceGrpcTransport.__doc__


class CustomerClientLinkServiceGrpcTransport(
    customer_client_link_service_grpc_transport.CustomerClientLinkServiceGrpcTransport):
    __doc__ = customer_client_link_service_grpc_transport.CustomerClientLinkServiceGrpcTransport.__doc__


class CustomerClientServiceGrpcTransport(
    customer_client_service_grpc_transport.CustomerClientServiceGrpcTransport):
    __doc__ = customer_client_service_grpc_transport.CustomerClientServiceGrpcTransport.__doc__


class CustomerExtensionSettingServiceGrpcTransport(
    customer_extension_setting_service_grpc_transport.CustomerExtensionSettingServiceGrpcTransport):
    __doc__ = customer_extension_setting_service_grpc_transport.CustomerExtensionSettingServiceGrpcTransport.__doc__


class CustomerFeedServiceGrpcTransport(
    customer_feed_service_grpc_transport.CustomerFeedServiceGrpcTransport):
    __doc__ = customer_feed_service_grpc_transport.CustomerFeedServiceGrpcTransport.__doc__


class CustomerLabelServiceGrpcTransport(
    customer_label_service_grpc_transport.CustomerLabelServiceGrpcTransport):
    __doc__ = customer_label_service_grpc_transport.CustomerLabelServiceGrpcTransport.__doc__


class CustomerManagerLinkServiceGrpcTransport(
    customer_manager_link_service_grpc_transport.CustomerManagerLinkServiceGrpcTransport):
    __doc__ = customer_manager_link_service_grpc_transport.CustomerManagerLinkServiceGrpcTransport.__doc__


class CustomerNegativeCriterionServiceGrpcTransport(
    customer_negative_criterion_service_grpc_transport.CustomerNegativeCriterionServiceGrpcTransport):
    __doc__ = customer_negative_criterion_service_grpc_transport.CustomerNegativeCriterionServiceGrpcTransport.__doc__


class CustomerServiceGrpcTransport(
    customer_service_grpc_transport.CustomerServiceGrpcTransport):
    __doc__ = customer_service_grpc_transport.CustomerServiceGrpcTransport.__doc__


class CustomInterestServiceGrpcTransport(
    custom_interest_service_grpc_transport.CustomInterestServiceGrpcTransport):
    __doc__ = custom_interest_service_grpc_transport.CustomInterestServiceGrpcTransport.__doc__


class DetailPlacementViewServiceGrpcTransport(
    detail_placement_view_service_grpc_transport.DetailPlacementViewServiceGrpcTransport):
    __doc__ = detail_placement_view_service_grpc_transport.DetailPlacementViewServiceGrpcTransport.__doc__


class DisplayKeywordViewServiceGrpcTransport(
    display_keyword_view_service_grpc_transport.DisplayKeywordViewServiceGrpcTransport):
    __doc__ = display_keyword_view_service_grpc_transport.DisplayKeywordViewServiceGrpcTransport.__doc__


class DomainCategoryServiceGrpcTransport(
    domain_category_service_grpc_transport.DomainCategoryServiceGrpcTransport):
    __doc__ = domain_category_service_grpc_transport.DomainCategoryServiceGrpcTransport.__doc__


class DynamicSearchAdsSearchTermViewServiceGrpcTransport(
    dynamic_search_ads_search_term_view_service_grpc_transport.DynamicSearchAdsSearchTermViewServiceGrpcTransport):
    __doc__ = dynamic_search_ads_search_term_view_service_grpc_transport.DynamicSearchAdsSearchTermViewServiceGrpcTransport.__doc__


class ExpandedLandingPageViewServiceGrpcTransport(
    expanded_landing_page_view_service_grpc_transport.ExpandedLandingPageViewServiceGrpcTransport):
    __doc__ = expanded_landing_page_view_service_grpc_transport.ExpandedLandingPageViewServiceGrpcTransport.__doc__


class ExtensionFeedItemServiceGrpcTransport(
    extension_feed_item_service_grpc_transport.ExtensionFeedItemServiceGrpcTransport):
    __doc__ = extension_feed_item_service_grpc_transport.ExtensionFeedItemServiceGrpcTransport.__doc__


class FeedItemServiceGrpcTransport(
    feed_item_service_grpc_transport.FeedItemServiceGrpcTransport):
    __doc__ = feed_item_service_grpc_transport.FeedItemServiceGrpcTransport.__doc__


class FeedItemTargetServiceGrpcTransport(
    feed_item_target_service_grpc_transport.FeedItemTargetServiceGrpcTransport):
    __doc__ = feed_item_target_service_grpc_transport.FeedItemTargetServiceGrpcTransport.__doc__


class FeedMappingServiceGrpcTransport(
    feed_mapping_service_grpc_transport.FeedMappingServiceGrpcTransport):
    __doc__ = feed_mapping_service_grpc_transport.FeedMappingServiceGrpcTransport.__doc__


class FeedPlaceholderViewServiceGrpcTransport(
    feed_placeholder_view_service_grpc_transport.FeedPlaceholderViewServiceGrpcTransport):
    __doc__ = feed_placeholder_view_service_grpc_transport.FeedPlaceholderViewServiceGrpcTransport.__doc__


class FeedServiceGrpcTransport(
    feed_service_grpc_transport.FeedServiceGrpcTransport):
    __doc__ = feed_service_grpc_transport.FeedServiceGrpcTransport.__doc__


class GenderViewServiceGrpcTransport(
    gender_view_service_grpc_transport.GenderViewServiceGrpcTransport):
    __doc__ = gender_view_service_grpc_transport.GenderViewServiceGrpcTransport.__doc__


class GeographicViewServiceGrpcTransport(
    geographic_view_service_grpc_transport.GeographicViewServiceGrpcTransport):
    __doc__ = geographic_view_service_grpc_transport.GeographicViewServiceGrpcTransport.__doc__


class GeoTargetConstantServiceGrpcTransport(
    geo_target_constant_service_grpc_transport.GeoTargetConstantServiceGrpcTransport):
    __doc__ = geo_target_constant_service_grpc_transport.GeoTargetConstantServiceGrpcTransport.__doc__


class GoogleAdsFieldServiceGrpcTransport(
    google_ads_field_service_grpc_transport.GoogleAdsFieldServiceGrpcTransport):
    __doc__ = google_ads_field_service_grpc_transport.GoogleAdsFieldServiceGrpcTransport.__doc__


class GoogleAdsServiceGrpcTransport(
    google_ads_service_grpc_transport.GoogleAdsServiceGrpcTransport):
    __doc__ = google_ads_service_grpc_transport.GoogleAdsServiceGrpcTransport.__doc__


class GroupPlacementViewServiceGrpcTransport(
    group_placement_view_service_grpc_transport.GroupPlacementViewServiceGrpcTransport):
    __doc__ = group_placement_view_service_grpc_transport.GroupPlacementViewServiceGrpcTransport.__doc__


class HotelGroupViewServiceGrpcTransport(
    hotel_group_view_service_grpc_transport.HotelGroupViewServiceGrpcTransport):
    __doc__ = hotel_group_view_service_grpc_transport.HotelGroupViewServiceGrpcTransport.__doc__


class HotelPerformanceViewServiceGrpcTransport(
    hotel_performance_view_service_grpc_transport.HotelPerformanceViewServiceGrpcTransport):
    __doc__ = hotel_performance_view_service_grpc_transport.HotelPerformanceViewServiceGrpcTransport.__doc__


class KeywordPlanAdGroupServiceGrpcTransport(
    keyword_plan_ad_group_service_grpc_transport.KeywordPlanAdGroupServiceGrpcTransport):
    __doc__ = keyword_plan_ad_group_service_grpc_transport.KeywordPlanAdGroupServiceGrpcTransport.__doc__


class KeywordPlanCampaignServiceGrpcTransport(
    keyword_plan_campaign_service_grpc_transport.KeywordPlanCampaignServiceGrpcTransport):
    __doc__ = keyword_plan_campaign_service_grpc_transport.KeywordPlanCampaignServiceGrpcTransport.__doc__


class KeywordPlanIdeaServiceGrpcTransport(
    keyword_plan_idea_service_grpc_transport.KeywordPlanIdeaServiceGrpcTransport):
    __doc__ = keyword_plan_idea_service_grpc_transport.KeywordPlanIdeaServiceGrpcTransport.__doc__


class KeywordPlanKeywordServiceGrpcTransport(
    keyword_plan_keyword_service_grpc_transport.KeywordPlanKeywordServiceGrpcTransport):
    __doc__ = keyword_plan_keyword_service_grpc_transport.KeywordPlanKeywordServiceGrpcTransport.__doc__


class KeywordPlanNegativeKeywordServiceGrpcTransport(
    keyword_plan_negative_keyword_service_grpc_transport.KeywordPlanNegativeKeywordServiceGrpcTransport):
    __doc__ = keyword_plan_negative_keyword_service_grpc_transport.KeywordPlanNegativeKeywordServiceGrpcTransport.__doc__


class KeywordPlanServiceGrpcTransport(
    keyword_plan_service_grpc_transport.KeywordPlanServiceGrpcTransport):
    __doc__ = keyword_plan_service_grpc_transport.KeywordPlanServiceGrpcTransport.__doc__


class KeywordViewServiceGrpcTransport(
    keyword_view_service_grpc_transport.KeywordViewServiceGrpcTransport):
    __doc__ = keyword_view_service_grpc_transport.KeywordViewServiceGrpcTransport.__doc__


class LabelServiceGrpcTransport(
    label_service_grpc_transport.LabelServiceGrpcTransport):
    __doc__ = label_service_grpc_transport.LabelServiceGrpcTransport.__doc__


class LandingPageViewServiceGrpcTransport(
    landing_page_view_service_grpc_transport.LandingPageViewServiceGrpcTransport):
    __doc__ = landing_page_view_service_grpc_transport.LandingPageViewServiceGrpcTransport.__doc__


class LanguageConstantServiceGrpcTransport(
    language_constant_service_grpc_transport.LanguageConstantServiceGrpcTransport):
    __doc__ = language_constant_service_grpc_transport.LanguageConstantServiceGrpcTransport.__doc__


class LocationViewServiceGrpcTransport(
    location_view_service_grpc_transport.LocationViewServiceGrpcTransport):
    __doc__ = location_view_service_grpc_transport.LocationViewServiceGrpcTransport.__doc__


class ManagedPlacementViewServiceGrpcTransport(
    managed_placement_view_service_grpc_transport.ManagedPlacementViewServiceGrpcTransport):
    __doc__ = managed_placement_view_service_grpc_transport.ManagedPlacementViewServiceGrpcTransport.__doc__


class MediaFileServiceGrpcTransport(
    media_file_service_grpc_transport.MediaFileServiceGrpcTransport):
    __doc__ = media_file_service_grpc_transport.MediaFileServiceGrpcTransport.__doc__


class MerchantCenterLinkServiceGrpcTransport(
    merchant_center_link_service_grpc_transport.MerchantCenterLinkServiceGrpcTransport):
    __doc__ = merchant_center_link_service_grpc_transport.MerchantCenterLinkServiceGrpcTransport.__doc__


class MobileAppCategoryConstantServiceGrpcTransport(
    mobile_app_category_constant_service_grpc_transport.MobileAppCategoryConstantServiceGrpcTransport):
    __doc__ = mobile_app_category_constant_service_grpc_transport.MobileAppCategoryConstantServiceGrpcTransport.__doc__


class MobileDeviceConstantServiceGrpcTransport(
    mobile_device_constant_service_grpc_transport.MobileDeviceConstantServiceGrpcTransport):
    __doc__ = mobile_device_constant_service_grpc_transport.MobileDeviceConstantServiceGrpcTransport.__doc__


class MutateJobServiceGrpcTransport(
    mutate_job_service_grpc_transport.MutateJobServiceGrpcTransport):
    __doc__ = mutate_job_service_grpc_transport.MutateJobServiceGrpcTransport.__doc__


class OperatingSystemVersionConstantServiceGrpcTransport(
    operating_system_version_constant_service_grpc_transport.OperatingSystemVersionConstantServiceGrpcTransport):
    __doc__ = operating_system_version_constant_service_grpc_transport.OperatingSystemVersionConstantServiceGrpcTransport.__doc__


class PaidOrganicSearchTermViewServiceGrpcTransport(
    paid_organic_search_term_view_service_grpc_transport.PaidOrganicSearchTermViewServiceGrpcTransport):
    __doc__ = paid_organic_search_term_view_service_grpc_transport.PaidOrganicSearchTermViewServiceGrpcTransport.__doc__


class ParentalStatusViewServiceGrpcTransport(
    parental_status_view_service_grpc_transport.ParentalStatusViewServiceGrpcTransport):
    __doc__ = parental_status_view_service_grpc_transport.ParentalStatusViewServiceGrpcTransport.__doc__


class PaymentsAccountServiceGrpcTransport(
    payments_account_service_grpc_transport.PaymentsAccountServiceGrpcTransport):
    __doc__ = payments_account_service_grpc_transport.PaymentsAccountServiceGrpcTransport.__doc__


class ProductBiddingCategoryConstantServiceGrpcTransport(
    product_bidding_category_constant_service_grpc_transport.ProductBiddingCategoryConstantServiceGrpcTransport):
    __doc__ = product_bidding_category_constant_service_grpc_transport.ProductBiddingCategoryConstantServiceGrpcTransport.__doc__


class ProductGroupViewServiceGrpcTransport(
    product_group_view_service_grpc_transport.ProductGroupViewServiceGrpcTransport):
    __doc__ = product_group_view_service_grpc_transport.ProductGroupViewServiceGrpcTransport.__doc__


class RecommendationServiceGrpcTransport(
    recommendation_service_grpc_transport.RecommendationServiceGrpcTransport):
    __doc__ = recommendation_service_grpc_transport.RecommendationServiceGrpcTransport.__doc__


class RemarketingActionServiceGrpcTransport(
    remarketing_action_service_grpc_transport.RemarketingActionServiceGrpcTransport):
    __doc__ = remarketing_action_service_grpc_transport.RemarketingActionServiceGrpcTransport.__doc__


class SearchTermViewServiceGrpcTransport(
    search_term_view_service_grpc_transport.SearchTermViewServiceGrpcTransport):
    __doc__ = search_term_view_service_grpc_transport.SearchTermViewServiceGrpcTransport.__doc__


class SharedCriterionServiceGrpcTransport(
    shared_criterion_service_grpc_transport.SharedCriterionServiceGrpcTransport):
    __doc__ = shared_criterion_service_grpc_transport.SharedCriterionServiceGrpcTransport.__doc__


class SharedSetServiceGrpcTransport(
    shared_set_service_grpc_transport.SharedSetServiceGrpcTransport):
    __doc__ = shared_set_service_grpc_transport.SharedSetServiceGrpcTransport.__doc__


class ShoppingPerformanceViewServiceGrpcTransport(
    shopping_performance_view_service_grpc_transport.ShoppingPerformanceViewServiceGrpcTransport):
    __doc__ = shopping_performance_view_service_grpc_transport.ShoppingPerformanceViewServiceGrpcTransport.__doc__


class TopicConstantServiceGrpcTransport(
    topic_constant_service_grpc_transport.TopicConstantServiceGrpcTransport):
    __doc__ = topic_constant_service_grpc_transport.TopicConstantServiceGrpcTransport.__doc__


class TopicViewServiceGrpcTransport(
    topic_view_service_grpc_transport.TopicViewServiceGrpcTransport):
    __doc__ = topic_view_service_grpc_transport.TopicViewServiceGrpcTransport.__doc__


class UserInterestServiceGrpcTransport(
    user_interest_service_grpc_transport.UserInterestServiceGrpcTransport):
    __doc__ = user_interest_service_grpc_transport.UserInterestServiceGrpcTransport.__doc__


class UserListServiceGrpcTransport(
    user_list_service_grpc_transport.UserListServiceGrpcTransport):
    __doc__ = user_list_service_grpc_transport.UserListServiceGrpcTransport.__doc__


class VideoServiceGrpcTransport(
    video_service_grpc_transport.VideoServiceGrpcTransport):
    __doc__ = video_service_grpc_transport.VideoServiceGrpcTransport.__doc__


__all__ = (
    'enums',
    'types',
    'AccountBudgetProposalServiceClient',
    'AccountBudgetServiceClient',
    'AdGroupAdLabelServiceClient',
    'AdGroupAdServiceClient',
    'AdGroupAudienceViewServiceClient',
    'AdGroupBidModifierServiceClient',
    'AdGroupCriterionLabelServiceClient',
    'AdGroupCriterionServiceClient',
    'AdGroupCriterionSimulationServiceClient',
    'AdGroupExtensionSettingServiceClient',
    'AdGroupFeedServiceClient',
    'AdGroupLabelServiceClient',
    'AdGroupServiceClient',
    'AdGroupSimulationServiceClient',
    'AdParameterServiceClient',
    'AdScheduleViewServiceClient',
    'AgeRangeViewServiceClient',
    'AssetServiceClient',
    'BiddingStrategyServiceClient',
    'BillingSetupServiceClient',
    'CampaignAudienceViewServiceClient',
    'CampaignBidModifierServiceClient',
    'CampaignBudgetServiceClient',
    'CampaignCriterionServiceClient',
    'CampaignCriterionSimulationServiceClient',
    'CampaignDraftServiceClient',
    'CampaignExperimentServiceClient',
    'CampaignExtensionSettingServiceClient',
    'CampaignFeedServiceClient',
    'CampaignLabelServiceClient',
    'CampaignServiceClient',
    'CampaignSharedSetServiceClient',
    'CarrierConstantServiceClient',
    'ChangeStatusServiceClient',
    'ClickViewServiceClient',
    'ConversionActionServiceClient',
    'ConversionAdjustmentUploadServiceClient',
    'ConversionUploadServiceClient',
    'CustomerClientLinkServiceClient',
    'CustomerClientServiceClient',
    'CustomerExtensionSettingServiceClient',
    'CustomerFeedServiceClient',
    'CustomerLabelServiceClient',
    'CustomerManagerLinkServiceClient',
    'CustomerNegativeCriterionServiceClient',
    'CustomerServiceClient',
    'CustomInterestServiceClient',
    'DetailPlacementViewServiceClient',
    'DisplayKeywordViewServiceClient',
    'DomainCategoryServiceClient',
    'DynamicSearchAdsSearchTermViewServiceClient',
    'ExpandedLandingPageViewServiceClient',
    'ExtensionFeedItemServiceClient',
    'FeedItemServiceClient',
    'FeedItemTargetServiceClient',
    'FeedMappingServiceClient',
    'FeedPlaceholderViewServiceClient',
    'FeedServiceClient',
    'GenderViewServiceClient',
    'GeographicViewServiceClient',
    'GeoTargetConstantServiceClient',
    'GoogleAdsFieldServiceClient',
    'GoogleAdsServiceClient',
    'GroupPlacementViewServiceClient',
    'HotelGroupViewServiceClient',
    'HotelPerformanceViewServiceClient',
    'KeywordPlanAdGroupServiceClient',
    'KeywordPlanCampaignServiceClient',
    'KeywordPlanIdeaServiceClient',
    'KeywordPlanKeywordServiceClient',
    'KeywordPlanNegativeKeywordServiceClient',
    'KeywordPlanServiceClient',
    'KeywordViewServiceClient',
    'LabelServiceClient',
    'LandingPageViewServiceClient',
    'LanguageConstantServiceClient',
    'LocationViewServiceClient',
    'ManagedPlacementViewServiceClient',
    'MediaFileServiceClient',
    'MerchantCenterLinkServiceClient',
    'MobileAppCategoryConstantServiceClient',
    'MobileDeviceConstantServiceClient',
    'MutateJobServiceClient',
    'OperatingSystemVersionConstantServiceClient',
    'PaidOrganicSearchTermViewServiceClient',
    'ParentalStatusViewServiceClient',
    'PaymentsAccountServiceClient',
    'ProductBiddingCategoryConstantServiceClient',
    'ProductGroupViewServiceClient',
    'RecommendationServiceClient',
    'RemarketingActionServiceClient',
    'SearchTermViewServiceClient',
    'SharedCriterionServiceClient',
    'SharedSetServiceClient',
    'ShoppingPerformanceViewServiceClient',
    'TopicConstantServiceClient',
    'TopicViewServiceClient',
    'UserInterestServiceClient',
    'UserListServiceClient',
    'VideoServiceClient',
    'AccountBudgetProposalServiceGrpcTransport',
    'AccountBudgetServiceGrpcTransport',
    'AdGroupAdLabelServiceGrpcTransport',
    'AdGroupAdServiceGrpcTransport',
    'AdGroupAudienceViewServiceGrpcTransport',
    'AdGroupBidModifierServiceGrpcTransport',
    'AdGroupCriterionLabelServiceGrpcTransport',
    'AdGroupCriterionServiceGrpcTransport',
    'AdGroupCriterionSimulationServiceGrpcTransport',
    'AdGroupExtensionSettingServiceGrpcTransport',
    'AdGroupFeedServiceGrpcTransport',
    'AdGroupLabelServiceGrpcTransport',
    'AdGroupServiceGrpcTransport',
    'AdGroupSimulationServiceGrpcTransport',
    'AdParameterServiceGrpcTransport',
    'AdScheduleViewServiceGrpcTransport',
    'AgeRangeViewServiceGrpcTransport',
    'AssetServiceGrpcTransport',
    'BiddingStrategyServiceGrpcTransport',
    'BillingSetupServiceGrpcTransport',
    'CampaignAudienceViewServiceGrpcTransport',
    'CampaignBidModifierServiceGrpcTransport',
    'CampaignBudgetServiceGrpcTransport',
    'CampaignCriterionServiceGrpcTransport',
    'CampaignCriterionSimulationServiceGrpcTransport',
    'CampaignDraftServiceGrpcTransport',
    'CampaignExperimentServiceGrpcTransport',
    'CampaignExtensionSettingServiceGrpcTransport',
    'CampaignFeedServiceGrpcTransport',
    'CampaignLabelServiceGrpcTransport',
    'CampaignServiceGrpcTransport',
    'CampaignSharedSetServiceGrpcTransport',
    'CarrierConstantServiceGrpcTransport',
    'ChangeStatusServiceGrpcTransport',
    'ClickViewServiceGrpcTransport',
    'ConversionActionServiceGrpcTransport',
    'ConversionAdjustmentUploadServiceGrpcTransport',
    'ConversionUploadServiceGrpcTransport',
    'CustomerClientLinkServiceGrpcTransport',
    'CustomerClientServiceGrpcTransport',
    'CustomerExtensionSettingServiceGrpcTransport',
    'CustomerFeedServiceGrpcTransport',
    'CustomerLabelServiceGrpcTransport',
    'CustomerManagerLinkServiceGrpcTransport',
    'CustomerNegativeCriterionServiceGrpcTransport',
    'CustomerServiceGrpcTransport',
    'CustomInterestServiceGrpcTransport',
    'DetailPlacementViewServiceGrpcTransport',
    'DisplayKeywordViewServiceGrpcTransport',
    'DomainCategoryServiceGrpcTransport',
    'DynamicSearchAdsSearchTermViewServiceGrpcTransport',
    'ExpandedLandingPageViewServiceGrpcTransport',
    'ExtensionFeedItemServiceGrpcTransport',
    'FeedItemServiceGrpcTransport',
    'FeedItemTargetServiceGrpcTransport',
    'FeedMappingServiceGrpcTransport',
    'FeedPlaceholderViewServiceGrpcTransport',
    'FeedServiceGrpcTransport',
    'GenderViewServiceGrpcTransport',
    'GeographicViewServiceGrpcTransport',
    'GeoTargetConstantServiceGrpcTransport',
    'GoogleAdsFieldServiceGrpcTransport',
    'GoogleAdsServiceGrpcTransport',
    'GroupPlacementViewServiceGrpcTransport',
    'HotelGroupViewServiceGrpcTransport',
    'HotelPerformanceViewServiceGrpcTransport',
    'KeywordPlanAdGroupServiceGrpcTransport',
    'KeywordPlanCampaignServiceGrpcTransport',
    'KeywordPlanIdeaServiceGrpcTransport',
    'KeywordPlanKeywordServiceGrpcTransport',
    'KeywordPlanNegativeKeywordServiceGrpcTransport',
    'KeywordPlanServiceGrpcTransport',
    'KeywordViewServiceGrpcTransport',
    'LabelServiceGrpcTransport',
    'LandingPageViewServiceGrpcTransport',
    'LanguageConstantServiceGrpcTransport',
    'LocationViewServiceGrpcTransport',
    'ManagedPlacementViewServiceGrpcTransport',
    'MediaFileServiceGrpcTransport',
    'MerchantCenterLinkServiceGrpcTransport',
    'MobileAppCategoryConstantServiceGrpcTransport',
    'MobileDeviceConstantServiceGrpcTransport',
    'MutateJobServiceGrpcTransport',
    'OperatingSystemVersionConstantServiceGrpcTransport',
    'PaidOrganicSearchTermViewServiceGrpcTransport',
    'ParentalStatusViewServiceGrpcTransport',
    'PaymentsAccountServiceGrpcTransport',
    'ProductBiddingCategoryConstantServiceGrpcTransport',
    'ProductGroupViewServiceGrpcTransport',
    'RecommendationServiceGrpcTransport',
    'RemarketingActionServiceGrpcTransport',
    'SearchTermViewServiceGrpcTransport',
    'SharedCriterionServiceGrpcTransport',
    'SharedSetServiceGrpcTransport',
    'ShoppingPerformanceViewServiceGrpcTransport',
    'TopicConstantServiceGrpcTransport',
    'TopicViewServiceGrpcTransport',
    'UserInterestServiceGrpcTransport',
    'UserListServiceGrpcTransport',
    'VideoServiceGrpcTransport',
)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/enums/month_of_year.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/enums/month_of_year.proto',
  package='google.ads.googleads.v1.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v1.enumsB\020MonthOfYearProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V1.Enums\312\002\035Google\\Ads\\GoogleAds\\V1\\Enums\352\002!Google::Ads::GoogleAds::V1::Enums'),
  serialized_pb=_b('\n7google/ads/googleads_v1/proto/enums/month_of_year.proto\x12\x1dgoogle.ads.googleads.v1.enums\x1a\x1cgoogle/api/annotations.proto\"\xd1\x01\n\x0fMonthOfYearEnum\"\xbd\x01\n\x0bMonthOfYear\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0b\n\x07JANUARY\x10\x02\x12\x0c\n\x08\x46\x45\x42RUARY\x10\x03\x12\t\n\x05MARCH\x10\x04\x12\t\n\x05\x41PRIL\x10\x05\x12\x07\n\x03MAY\x10\x06\x12\x08\n\x04JUNE\x10\x07\x12\x08\n\x04JULY\x10\x08\x12\n\n\x06\x41UGUST\x10\t\x12\r\n\tSEPTEMBER\x10\n\x12\x0b\n\x07OCTOBER\x10\x0b\x12\x0c\n\x08NOVEMBER\x10\x0c\x12\x0c\n\x08\x44\x45\x43\x45MBER\x10\rB\xe5\x01\n!com.google.ads.googleads.v1.enumsB\x10MonthOfYearProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V1.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V1\\Enums\xea\x02!Google::Ads::GoogleAds::V1::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_MONTHOFYEARENUM_MONTHOFYEAR = _descriptor.EnumDescriptor(
  name='MonthOfYear',
  full_name='google.ads.googleads.v1.enums.MonthOfYearEnum.MonthOfYear',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JANUARY', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEBRUARY', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MARCH', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='APRIL', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MAY', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JUNE', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='JULY', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='AUGUST', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SEPTEMBER', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='OCTOBER', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NOVEMBER', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DECEMBER', index=13, number=13,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=141,
  serialized_end=330,
)
_sym_db.RegisterEnumDescriptor(_MONTHOFYEARENUM_MONTHOFYEAR)


_MONTHOFYEARENUM = _descriptor.Descriptor(
  name='MonthOfYearEnum',
  full_name='google.ads.googleads.v1.enums.MonthOfYearEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _MONTHOFYEARENUM_MONTHOFYEAR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=330,
)

_MONTHOFYEARENUM_MONTHOFYEAR.containing_type = _MONTHOFYEARENUM
DESCRIPTOR.message_types_by_name['MonthOfYearEnum'] = _MONTHOFYEARENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

MonthOfYearEnum = _reflection.GeneratedProtocolMessageType('MonthOfYearEnum', (_message.Message,), dict(
  DESCRIPTOR = _MONTHOFYEARENUM,
  __module__ = 'google.ads.googleads_v1.proto.enums.month_of_year_pb2'
  ,
  __doc__ = """Container for enumeration of months of the year, e.g., "January".
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.enums.MonthOfYearEnum)
  ))
_sym_db.RegisterMessage(MonthOfYearEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
